# Generated by Django 6.0.1 on 2026-01-22 10:33

from django.db import migrations, models


class Migration(migrations.Migration):

    dependencies = [
        ("tests", "0001_initial"),
    ]

    operations = [
        migrations.CreateModel(
            name="Event",
            fields=[
                (
                    "id",
                    models.BigAutoField(
                        auto_created=True,
                        primary_key=True,
                        serialize=False,
                        verbose_name="ID",
                    ),
                ),
                ("name", models.CharField(max_length=200)),
                ("event_date", models.DateField()),
                ("created_at", models.DateTimeField()),
                ("start_time", models.TimeField()),
                ("duration", models.DurationField()),
                ("event_id", models.UUIDField()),
            ],
        ),
    ]
